<?php

/**
* 
*
*
* Adds a setting page
*/
add_action('admin_menu','tap_the_web_catalog_menu');
function tap_the_web_catalog_menu() {

  add_options_page(
        tap_the_web_catalog_plugin_name(),
        tap_the_web_catalog_plugin_name(),
      'manage_options',
      'tap-the-web-catalog',
      'tap_the_web_catalog_options_page'    
  );
}
/**
* 
*
*
* Adds link to settings page on plugin listing page
*/
function tap_the_web_catalog_add_settings_link( $links ) {
  $settings_link = '<a href="options-general.php?page=tap-the-web-catalog">' . __( 'Settings','tap-the-web-catalog' ) . '</a>';
  array_unshift( $links, $settings_link );
  return $links;
}
$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'tap_the_web_catalog_add_settings_link' );
/**
* 
*
*
* Output the settings page content
*/
function tap_the_web_catalog_options_page(){

  //output styles and scripts
  wp_enqueue_script(array('tap_the_web_catalog_admin_script','tap_the_web_catalog_sweet_alert_script'));
  wp_enqueue_style(array('tap_the_web_catalog_admin_style','tap_the_web_catalog_sweet_alert_style'));

  //get existing settings
  $option_name = 'tap_the_web_catalog_settings';

  if(!get_option($option_name)){
      add_option($option_name, array());
  }  

  $option = get_option($option_name);

  //start output
  $html = '';

  //wrapper
  $html .= '<div id="tap-the-web-catalog-settings-page" class="wrap">';

    //heading
    $html .= '<h1 id="tap-the-web-catalog-settings-heading"><span class="dashicons dashicons-admin-settings"></span> '.__(tap_the_web_catalog_plugin_name(), 'tap-the-web-catalog' ).' '.__('Settings', 'tap-the-web-catalog' ).'</h1>';

    //start settings

    //section start
    $html .= '<h2>'.__('General Settings', 'tap-the-web-catalog' ).'</h2><hr>';


    $html .= '<fieldset>';
        $html .= '<label>'.__('API key', 'tap-the-web-catalog' ).'</label>';
        //set default
        if(!array_key_exists('api-key',$option)){
            $option['api-key'] = '';
        }

        $html .= '<input type="password" name="api-key" class="tap-the-web-catalog-setting" value="'.$option['api-key'].'">';
    $html .= '</fieldset>';
    
    $html .= '<fieldset>';
        $html .= '<label>'.__('Number of times a week to perform sync', 'tap-the-web-catalog' ).'</label>';
        // $html .= '<em class="help-text">'.__('Set to 0 to turn off sync', 'tap-the-web-catalog' ).'</em>';
        //set default
        if(!array_key_exists('syncs-a-week',$option)){
            $option['syncs-a-week'] = 1;
        }

        $html .= '<input type="number" min="1" max="7" name="syncs-a-week" class="tap-the-web-catalog-setting" value="'.$option['syncs-a-week'].'">';
    $html .= '</fieldset>';



        $html .= '<fieldset>';
            $html .= '<label>'.__('Enable Brands', 'tap-the-web-catalog' ).'</label>';
            // $html .= '<em class="help-text">'.__('', 'tap-the-web-catalog' ).'</em>';

            //set default
            if(array_key_exists('disable-select-brands',$option)){
                $selected_brands_as_array = explode(',',$option['disable-select-brands']);
            } else {
                $selected_brands_as_array = array('');
                $option['disable-select-brands'] = '';
            }
            
            $html .= '<ul class="brands-list">';

                //only print list if api key exists
                if(array_key_exists('api-key',$option)){
              
                    $data = tap_the_web_catalog_api_data();

                    $brands = $data['manufacturers'];

                    foreach($brands as $brand_slug => $brand_data){
                        $html .= '<li>';

                            if(in_array($brand_slug,$selected_brands_as_array)){
                                $checked = ' checked';
                            } else {
                                $checked = '';
                            }

                            $html .= '<input type="checkbox" name="'.$brand_slug.'" class="tap-the-web-catalog-brand-checkbox" '.$checked.'> '.$brand_data['name'];
                        $html .= '</li>';
                    }
                    
                }

            $html .= '</ul>';

            $html .= '<input type="text" id="disable-select-brands" name="disable-select-brands" class="tap-the-web-catalog-setting" value="'.$option['disable-select-brands'].'">';
        $html .= '</fieldset>';


      //submit button
      $html .= '<fieldset>';
          $html .= '<input type="submit" id="tap-the-web-catalog-save-settings" class="button button-primary" value="'.__( 'Save Settings', 'tap-the-web-catalog' ).'">';

          $html .= '<input type="submit" id="tap-the-web-catalog-run-initial-import" class="button button-secondary" value="'.__( 'Force Sync', 'tap-the-web-catalog' ).'">';

          $html .= '<input type="submit" id="tap-the-web-catalog-delete-all-products" class="button button-secondary" value="'.__( 'Delete All Products', 'tap-the-web-catalog' ).'">';
      $html .= '</fieldset>';


  $html .= '</div>';    

  echo $html;

}


/**
* 
*
*
* Save the admin settings
*/
function tap_the_web_catalog_save_settings() {

    //get variables
    $data = stripslashes($_POST['data']);

    $data_as_array = json_decode($data,true);

    $option_name = 'tap_the_web_catalog_settings';

    update_option($option_name, $data_as_array);

    //we also want to reschedule the event as the person might have updated the frequency of syncs
    wp_clear_scheduled_hook( 'tap_the_web_catalog_scheduled_sync' );
    wp_schedule_event( time(), 'times_per_week', 'tap_the_web_catalog_scheduled_sync' );

    wp_die(); 

}
add_action( 'wp_ajax_tap_the_web_catalog_save_settings', 'tap_the_web_catalog_save_settings' );
?>