<?php
/**
* 
*
*
* Does sync operation for a taxonomy
*/
function tap_the_web_catalog_sync_taxonomy($taxonomy_name){

    $option_name = 'tap_the_web_catalog_settings';
    $option = get_option($option_name);

    //get master data
    $master_catalog = tap_the_web_catalog_api_data();
    $master_catalog = $master_catalog[$taxonomy_name];

    //get catalog data
    $slave_catalog = array();

    $terms = get_terms( $taxonomy_name, array(
        'hide_empty' => false,
    ));

    $term_ids = array();

    foreach($terms as $term){
        $term_slug = $term->slug;
        $term_name = $term->name;
        $term_id = $term->term_id;

        $data = array(
            'slug' => $term_slug,
            'name' => $term_name,
        );

        if($taxonomy_name == 'manufacturers'){
            if(get_term_meta( $term_id, 'brand_image', true )){
                $data['image'] = get_term_meta( $term_id, 'brand_image', true );
            } else {
                $data['image'] = '';
            }
            
        }

        $slave_catalog[$term_slug] = $data;


        $term_ids[$term_slug] = $term_id;
    }

    //we now have 2 array we can work with

    //we need to do 3 operations, delete terms which no longer exist, create new terms and modify existing

    //lets delete
    foreach($slave_catalog as $slave_catalog_slug => $slave_catalog_data){

        //if the slug does not exist in the master catalog, delete it
        if(!array_key_exists($slave_catalog_slug,$master_catalog)){
            wp_delete_term( $term_ids[$slave_catalog_slug], $taxonomy_name );
        }
    }

    //lets create
    foreach($master_catalog as $master_catalog_slug => $master_catalog_data){
        if(!array_key_exists($master_catalog_slug,$slave_catalog)){

            //run special condition for brands/manufacturers
            
            if($taxonomy_name == 'manufacturers'){
                $selected_brands_as_array = explode(',',$option['disable-select-brands']);

                if(in_array($master_catalog_slug,$selected_brands_as_array)){
                    //create a term
                    $term_id = wp_insert_term(
                        $master_catalog_data['name'],   // the term 
                        $taxonomy_name, // the taxonomy
                        array(
                            'slug' => $master_catalog_slug,
                        )
                    ); 
                    
                    //now lets also add the image
                    add_term_meta( $term_id, 'brand_image', $master_catalog_data['image'] );
                    
                }

            } else {
                //create a term
                $term_id = wp_insert_term(
                    $master_catalog_data['name'],   // the term 
                    $taxonomy_name, // the taxonomy
                    array(
                        'slug' => $master_catalog_slug,
                    )
                );
            }

        }       
    }





    //lets modify
    foreach($slave_catalog as $slave_catalog_slug => $slave_catalog_data){

        $master_catalog_name = $master_catalog[$slave_catalog_slug]['name'];

        if($master_catalog_name != $slave_catalog_data['name']){
            //lets update the name of the slave catalog item
            wp_update_term( $term_ids[$slave_catalog_slug], $taxonomy_name, array(
                'name' => $master_catalog_name,
            ));
        }

        //lets also update the image
        $master_catalog_image = $master_catalog[$slave_catalog_slug]['image'];

        if($master_catalog_image != $slave_catalog_data['image']){
            //lets update the image of the slave catalog item
            update_term_meta( $term_ids[$slave_catalog_slug], 'brand_image',$master_catalog_image  );
        }

    }
    

}

/**
* 
*
*
* Finds out if there are any common items in 2 arrays
*/
function tap_the_web_array_matches($array_one,$array_two){

    $matches = false;

    foreach($array_one as $item) {
        if(in_array($item, $array_two)) {
            $matches = true;
            break;
        }
    }

    return $matches;

}
/**
* 
*
*
* Does sync operation
*/
add_action('init','tap_the_web_catalog_sync');
function tap_the_web_catalog_sync(){

    $option_name = 'tap_the_web_catalog_settings';
    $option = get_option($option_name);
    $selected_brands_as_array = explode(',',$option['disable-select-brands']);

    $option_name_status = 'tap_the_web_catalog_sync_status';
    $sync_status = get_option($option_name_status);

    //only continue if we need to sync
    if($sync_status == 'INITIAL SYNC' || $sync_status == 'SCHEDULED SYNC'){

        //do taxonomies first - we can do this in one big batch
        tap_the_web_catalog_sync_taxonomy('manufacturers');
        tap_the_web_catalog_sync_taxonomy('classes');
        tap_the_web_catalog_sync_taxonomy('types');

        //now lets do the products in batches

        //get master data
        $master_catalog = tap_the_web_catalog_api_data();
        $master_catalog = $master_catalog['products'];

        // var_dump(count($master_catalog));

        $slave_catalog = array();
        $slave_catalog_product_ids = array();

        //add product data
        $args = array(
            'numberposts' => -1,
            'post_type'   => 'ttw_products'
        );
        
        $products = get_posts( $args );

        if($products){
            foreach($products as $product){

                $product_id = $product->ID;
                $product_slug = $product->post_name;
                $product_name = $product->post_title;
                $product_content = get_the_content( null, false, $product_id );
                $product_image = get_the_post_thumbnail_url($product_id, 'full' );
                $product_order = $product->menu_order;

                $product_manufacturers = get_the_terms( $product_id, 'manufacturers' );
                if($product_manufacturers){
                    $product_manufacturers_slugs = wp_list_pluck($product_manufacturers, 'slug');
                } else {
                    $product_manufacturers_slugs = array();
                }

                $product_classes = get_the_terms( $product_id, 'classes' );
                if($product_classes){
                    $product_classes_slugs = wp_list_pluck($product_classes, 'slug');
                } else {
                    $product_classes_slugs = array();
                }


                $product_types = get_the_terms( $product_id, 'types' );
                if($product_types){
                    $product_types_slugs = wp_list_pluck($product_types, 'slug');
                } else {
                    $product_types_slugs = array();
                }

                $slave_catalog[$product_slug] = array(
                    'product_slug' => $product_slug,
                    'product_name' => $product_name,
                    'product_content' => base64_encode($product_content),
                    'product_image' => $product_image,
                    'product_manufacturers' => $product_manufacturers_slugs,
                    'product_classes' => $product_classes_slugs,
                    'product_types' => $product_types_slugs,
                    'product_order' => $product_order,
                );

                $slave_catalog_product_ids[$product_slug] = $product_id;

            }
        }

        //we now have the 2 catalogs in exactly the same format


        //we need to create products, edit products and delete products

        //start with delete
        foreach($slave_catalog as $slave_catalog_product_key => $slave_catalog_product_data){

            if(!array_key_exists($slave_catalog_product_key,$master_catalog)){
                //delete the product
                wp_delete_post( $slave_catalog_product_ids[$slave_catalog_product_key], false );
            }

            //also delete if brand is excluded from plugin settings
            $slave_products_brands = $slave_catalog_product_data['product_manufacturers'];
            $match = tap_the_web_array_matches($slave_products_brands,$selected_brands_as_array);
            if(!$match){
                wp_delete_post( $slave_catalog_product_ids[$slave_catalog_product_key], false );
            }

        }



        $master_catalog_keys = array_keys($master_catalog);
        $slugs_remaining_option_name = 'tap_the_web_catalog_sync_slugs_remaining';

        if(!get_option($slugs_remaining_option_name)){
            add_option($slugs_remaining_option_name, $master_catalog_keys);        
        } 

        $slugs_remaining = get_option($slugs_remaining_option_name);

        // var_dump('THE AMOUNT OF SLUGS REMAINING IS: '.count($slugs_remaining));

        $batch_quantity = 250;

        $slugs_processed = array();

        //now we need to process the above items
        for ($i = 0; $i < $batch_quantity; $i++){ 

            if(array_key_exists($i,$slugs_remaining)){

                $master_catalog_product_key = $slugs_remaining[$i];
                $master_catalog_product_data = $master_catalog[$master_catalog_product_key];  

                array_push($slugs_processed,$master_catalog_product_key);
        
                //check to see if brand is in excluded brand
                $matches = tap_the_web_array_matches($selected_brands_as_array,$master_catalog_product_data['product_manufacturers']);

                if($matches){


                    $args = array(
                        'post_type'    => 'ttw_products',
                        'post_status'  => 'publish',
                        'post_name'  => $master_catalog_product_data['product_slug'],
                        'post_title'   => $master_catalog_product_data['product_name'],
                        'menu_order'   => $master_catalog_product_data['product_order'],
                        'post_content'      => base64_decode($master_catalog_product_data['product_content']),
                        'meta_input'   => array(
                            'product_image' => $master_catalog_product_data['product_image'],
                        )
                    );

                    //if we are updating add the id to the args
                    if(array_key_exists($master_catalog_product_key,$slave_catalog)){
                        //we are updating
                        $args['ID'] = $slave_catalog_product_ids[$master_catalog_product_key];
                    }
                    
                    $product_id = wp_insert_post($args);

                    //now set the terms for the 3 taxonomies
                    wp_set_object_terms( $product_id, $master_catalog_product_data['product_manufacturers'], 'manufacturers', false );
                    wp_set_object_terms( $product_id, $master_catalog_product_data['product_classes'], 'classes', false );
                    wp_set_object_terms( $product_id, $master_catalog_product_data['product_types'], 'types', false );

                } //end matches
            } //end if array key exists

        } //end for loop

        //now we need to remove the slugs processed from our array
        $slugs_still_remaining = array_diff($slugs_remaining,$slugs_processed);
        $slugs_still_remaining = array_values($slugs_still_remaining); //we need to reset the keys - this is important
        // var_dump('THE AMOUNT OF SLUGS STILL REMAINING IS: '.count($slugs_still_remaining));
        update_option($slugs_remaining_option_name, $slugs_still_remaining);

        if(empty($slugs_still_remaining)){
            update_option($option_name_status, 'SYNC COMPLETED');
            delete_option($slugs_remaining_option_name);
        }

    }

}
?>